# GPAS client

The command line interface for the GPAS platform.

The client enables privacy-preserving sequence data submission and retrieval of analytical output files. Prior to
upload, sample identifiers are anonymised and human host sequences are removed. A multicore machine with 16GB of RAM
running Linux or MacOS is required.

See the documentation in `/docs` for details for using the client.

## Installation steps

Details on installing the client can be found in the [install.md](docs/install.md) file.

## Development

Detail on installing the client for development purposes can be found in [install-dev.md](docs/install-dev.md)

## Usage information

More in-depth usage information can be found in the generated [README_pypi.md](README_pypi.md) file which combines
all subcommand documentation.

## Support

For technical support, please open an issue or contact [gpas.support@eit.org](mailto:gpas.support@eit.org)
